@@ -26,7 +26,7 @@ class Trackimo(object):
             password=None,
             loop=self.__loop,
         )
-        _logger.debug("Have protocol")
+
         authData = await self.__protocol.restore_session(refresh_token)
         if not authData:
             raise UnableToAuthenticate("Not authenticated with Trackimo API")
@@ -37,6 +37,8 @@ class Trackimo(object):
         self.__account = await accountHandler.get()
         self.__devices = await deviceHandler.get()
 
+        self.__track = deviceHandler.track
+
         return self
 
     async def login(self, username, password):
@@ -65,6 +67,8 @@ class Trackimo(object):
         self.__account = await accountHandler.get()
         self.__devices = await deviceHandler.get()
 
+        self.__track = deviceHandler.track
+
         return self
 
     @property
@@ -86,4 +90,11 @@ class Trackimo(object):
         if not self.__account:
             _logger.error("No account details. Make sure to login() first.")
             return {}
-        return self.__account
\ No newline at end of file
+        return self.__account
+
+    @property
+    def track(self):
+        if not self.__track:
+            _logger.error("Unable to track, no devices available.")
+            return None
+        return self.__track
\ No newline at end of file
